[Webfunds-commits] java/webfunds/ricardian StripKeyException.java

Edwin Woudt edwin@cypherpunks.ai
Mon, 28 Aug 2000 10:38:33 -0400 (AST)


edwin       00/08/28 10:38:32

  Modified:    webfunds/ricardian StripKeyException.java
  Log:
  Add invalid key option.

Revision  Changes    Path
1.3       +5 -3      java/webfunds/ricardian/StripKeyException.java

Index: StripKeyException.java
===================================================================
RCS file: /home/webfunds/cvsroot/java/webfunds/ricardian/StripKeyException.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- StripKeyException.java	2000/08/27 21:57:25	1.2
+++ StripKeyException.java	2000/08/28 14:38:32	1.3
@@ -1,5 +1,5 @@
 /*
- * $Id: StripKeyException.java,v 1.2 2000/08/27 21:57:25 iang Exp $
+ * $Id: StripKeyException.java,v 1.3 2000/08/28 14:38:32 edwin Exp $
  *
  * Copyright (c) 2000 Systemics Inc on behalf of
  * the WebFunds Development Team.  All Rights Reserved.
@@ -19,7 +19,8 @@
                               NOT_SIGNED      = 4, // not signed by additional
                               TOO_MANY_SIGS   = 5, // too many sigs on key?
                               NO_SUCH_USERID  = 6, // that userId not there
-                              TOO_MANY_USERID = 7; // too many matching userIds
+                              TOO_MANY_USERID = 7, // too many matching userIds
+                              INVALID_KEY     = 8; // invalid key
 
     public static final String[] errors = {
                               "<not set, old Ex>",
@@ -29,7 +30,8 @@
                               "Not Signed by Signer",
                               "Too Many Sigs By Signer?",
                               "Not Fit For Purpose, No UserId",
-                              "Too Many UserIds For Matching",
+                              "Too Many Matching UserIds",
+                              "Invalid Key",
                               };